# test-data-covid 400bp v1.0.0

[![Generic badge](https://img.shields.io/badge/STATUS-draft-blue.svg)](https://labs.primalscheme.com/faqs)

> If you use this scheme please cite: test-citation:124

[primalscheme labs](https://labs.primalscheme.com/detail/test-data-covid/400/v1.0.0)

## Overviews

## Details

```json
{
    "ampliconsize": 400,
    "schemeversion": "v1.0.0",
    "schemename": "test-data-covid",
    "primer_bed_md5": "0e4dfb382cc989d84f552bf89b314f5c",
    "reference_fasta_md5": "d11d06b5d1eb1d85c69e341c3c026e08",
    "status": "draft",
    "citations": [
        "test-citation:124"
    ],
    "authors": [
        "artic"
    ],
    "algorithmversion": "primalscheme-test",
    "species": [
        10
    ],
    "license": "CC BY-SA 4.0",
    "primerclass": "primerschemes",
    "infoschema": "v2.1.0",
    "articbedversion": "v3.0",
    "collections": [],
    "links": {
        "protocols": [],
        "validation": [],
        "homepage": [],
        "vendors": [],
        "misc": []
    },
    "refselect": null,
    "description": null,
    "derivedfrom": null,
    "contactinfo": null
}
```



------------------------------------------------------------------------

This work is licensed under a [Creative Commons Attribution-ShareAlike 4.0 International License](http://creativecommons.org/licenses/by-sa/4.0/) 

![](https://i.creativecommons.org/l/by-sa/4.0/88x31.png)